@@ -28,15 +28,15 @@
 
 #include "batchextract.h"
 #include "ark_debug.h"
-#include "kerfuffle/extractiondialog.h"
-#include "kerfuffle/jobs.h"
-#include "kerfuffle/queries.h"
+#include "extractiondialog.h"
+#include "jobs.h"
+#include "queries.h"
 
 #include <KIO/JobTracker>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KRun>
-#include <kwidgetjobtracker.h>
+#include <KWidgetJobTracker>
 
 #include <QDir>
 #include <QFileInfo>
@@ -139,7 +139,7 @@ void BatchExtract::slotStartJob()
 void BatchExtract::showFailedFiles()
 {
     if (!m_failedFiles.isEmpty()) {
-        KMessageBox::informationList(0, i18n("The following files could not be extracted:"), m_failedFiles);
+        KMessageBox::informationList(nullptr, i18n("The following files could not be extracted:"), m_failedFiles);
     }
 }
 
@@ -156,7 +156,7 @@ void BatchExtract::slotResult(KJob *job)
         removeSubjob(job);
 
         if (job->error() != KJob::KilledJobError) {
-            KMessageBox::error(Q_NULLPTR, job->errorString().isEmpty() ?
+            KMessageBox::error(nullptr, job->errorString().isEmpty() ?
                                      i18n("There was an error during extraction.") : job->errorString());
         }
 
@@ -170,7 +170,7 @@ void BatchExtract::slotResult(KJob *job)
         if (openDestinationAfterExtraction()) {
             QUrl destination(destinationFolder());
             destination.setPath(QDir::cleanPath(destination.path()));
-            KRun::runUrl(destination, QStringLiteral("inode/directory"), 0);
+            KRun::runUrl(destination, QStringLiteral("inode/directory"), nullptr, KRun::RunExecutables, QString(), QByteArray());
         }
 
         qCDebug(ARK) << "Finished, emitting the result";
@@ -189,8 +189,9 @@ void BatchExtract::slotResult(KJob *job)
 void BatchExtract::forwardProgress(KJob *job, unsigned long percent)
 {
     Q_UNUSED(job)
-    int jobPart = 100 / m_initialJobCount;
-    setPercent(jobPart *(m_initialJobCount - subjobs().size()) + percent / m_initialJobCount);
+    auto jobPart = static_cast<ulong>(100 / m_initialJobCount);
+    auto remainingJobs = static_cast<ulong>(m_initialJobCount - subjobs().size());
+    setPercent(jobPart * remainingJobs + percent / static_cast<ulong>(m_initialJobCount));
 }
 
 void BatchExtract::addInput(const QUrl& url)
@@ -258,7 +259,7 @@ bool BatchExtract::showExtractDialog()
     // Only one archive, we need a LoadJob to get the single-folder and subfolder properties.
     // TODO: find a better way (e.g. let the dialog handle everything), otherwise we list
     // the archive twice (once here and once in the following BatchExtractJob).
-    Kerfuffle::LoadJob *loadJob = Q_NULLPTR;
+    Kerfuffle::LoadJob *loadJob = nullptr;
     if (m_inputs.size() == 1) {
         loadJob = Kerfuffle::Archive::load(m_inputs.at(0).toLocalFile(), this);
         // We need to access the job after result has been emitted, if the user rejects the dialog.
@@ -270,7 +271,7 @@ bool BatchExtract::showExtractDialog()
             }
 
             auto archive = qobject_cast<Kerfuffle::LoadJob*>(job)->archive();
-            dialog->setSingleFolderArchive(archive->isSingleFolder());
+            dialog->setExtractToSubfolder(archive->hasMultipleTopLevelEntries());
             dialog->setSubfolder(archive->subfolderName());
         });
 
