@@ -26,12 +26,17 @@
  */
 
 #include "pluginmanager.h"
+#include "ark_debug.h"
+#include "settings.h"
 
 #include <KConfigGroup>
 #include <KPluginLoader>
 #include <KSharedConfig>
 
+#include <QFileInfo>
 #include <QMimeDatabase>
+#include <QProcess>
+#include <QRegularExpression>
 #include <QSet>
 
 #include <algorithm>
@@ -136,6 +141,11 @@ QStringList PluginManager::supportedMimeTypes(MimeSortingMode mode) const
         supported.remove(QStringLiteral("application/x-lz4-compressed-tar"));
     }
 
+    // Remove entry for lzo-compressed tar if libarchive not linked against lzo and lzop executable not found in path.
+    if (!libarchiveHasLzo() && QStandardPaths::findExecutable(QStringLiteral("lzop")).isEmpty()) {
+        supported.remove(QStringLiteral("application/x-tzo"));
+    }
+
     if (mode == SortByComment) {
         return sortByComment(supported);
     }
@@ -165,6 +175,11 @@ QStringList PluginManager::supportedWriteMimeTypes(MimeSortingMode mode) const
         supported.remove(QStringLiteral("application/x-lz4-compressed-tar"));
     }
 
+    // Remove entry for lzo-compressed tar if libarchive not linked against lzo and lzop executable not found in path.
+    if (!libarchiveHasLzo() && QStandardPaths::findExecutable(QStringLiteral("lzop")).isEmpty()) {
+        supported.remove(QStringLiteral("application/x-tzo"));
+    }
+
     if (mode == SortByComment) {
         return sortByComment(supported);
     }
@@ -195,12 +210,6 @@ QVector<Plugin*> PluginManager::filterBy(const QVector<Plugin*> &plugins, const
 void PluginManager::loadPlugins()
 {
     const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("kerfuffle"));
-    // This class might be used from executables other than ark (e.g. the tests),
-    // so we need to specify the name of the config file.
-    // TODO: once we have a GUI in the settings dialog,
-    // use this group to write whether a plugin gets disabled.
-    const KConfigGroup conf(KSharedConfig::openConfig(QStringLiteral("arkrc")), "EnabledPlugins");
-
     QSet<QString> addedPlugins;
     foreach (const KPluginMetaData &metaData, plugins) {
         const auto pluginId = metaData.pluginId();
@@ -210,7 +219,7 @@ void PluginManager::loadPlugins()
         }
 
         Plugin *plugin = new Plugin(this, metaData);
-        plugin->setEnabled(conf.readEntry(pluginId, true));
+        plugin->setEnabled(!ArkSettings::disabledPlugins().contains(pluginId));
         addedPlugins << pluginId;
         m_plugins << plugin;
     }
@@ -246,4 +255,35 @@ QStringList PluginManager::sortByComment(const QSet<QString> &mimeTypes)
     return sortedMimeTypes;
 }
 
+bool PluginManager::libarchiveHasLzo()
+{
+    // Step 1: look for the libarchive plugin, which is built against libarchive.
+    const QString pluginPath = []() {
+        foreach (const QString &path, QCoreApplication::libraryPaths()) {
+            const QString pluginPath = QStringLiteral("%1/kerfuffle/kerfuffle_libarchive.so").arg(path);
+            if (QFileInfo::exists(pluginPath)) {
+                return pluginPath;
+            }
+        }
+
+        return QString();
+    }();
+
+    // Step 2: ldd the libarchive plugin to figure out the absolute libarchive path.
+    QProcess ldd;
+    ldd.start(QStringLiteral("ldd"), {pluginPath});
+    ldd.waitForFinished();
+    const QString output = QString::fromUtf8(ldd.readAllStandardOutput());
+    QRegularExpression regex(QStringLiteral("/.*/libarchive.so"));
+    if (!regex.match(output).hasMatch()) {
+        return false;
+    }
+
+    // Step 3: check whether libarchive links against liblzo.
+    const QString libarchivePath = regex.match(output).captured(0);
+    ldd.start(QStringLiteral("ldd"), {libarchivePath});
+    ldd.waitForFinished();
+    return ldd.readAllStandardOutput().contains(QByteArrayLiteral("lzo"));
+}
+
 }
